@@ -3,7 +3,7 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.60';
+our $VERSION = '1.61';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
@@ -12,12 +12,12 @@ use DateTime::TimeZone 0.79;
 use Params::Validate 1.20 qw( validate SCALAR BOOLEAN OBJECT CODEREF );
 use Try::Tiny;
 
-use Package::DeprecationManager -deprecations => {
+use Exporter qw( import );
+
+use Package::DeprecationManager 0.15 -deprecations => {
     'accessor writers' => '1.58',
 };
 
-use Exporter qw( import );
-
 our @EXPORT_OK = qw( strftime strptime );
 
 use constant PERL_58 => $] < 5.010;
@@ -1008,7 +1008,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.60
+version 1.61
 
 =head1 SYNOPSIS
 
